
Demos
=====

.. toctree::
   :maxdepth: 1
   :caption: RAIL Core Demos

   examples/core_examples/FileIO_DataStore.ipynb
   examples/core_examples/FluxtoMag_and_Deredden_example.ipynb
   examples/core_examples/Pipe_Example.ipynb
   examples/core_examples/Run_Pipe.ipynb
   examples/core_examples/hyperbolic_magnitude_test.ipynb
   examples/core_examples/iterator_test.ipynb

   
.. toctree::
   :maxdepth: 1
   :caption: RAIL Creation Demos

   examples/creation_examples/degradation-demo.ipynb
   examples/creation_examples/example_GridSelection_for_HSC.ipynb
   examples/creation_examples/example_ObsConditions.ipynb
   examples/creation_examples/example_SpecSelection_for_zCOSMOS.ipynb
   examples/creation_examples/photometric_realization_demo.ipynb
   examples/creation_examples/posterior-demo.ipynb


.. toctree::
   :maxdepth: 1
   :caption: RAIL Estimation Demos

   examples/estimation_examples/NZDir.ipynb
   examples/estimation_examples/RAIL_estimation_demo.ipynb
   examples/estimation_examples/SimpleSOM_demo.ipynb
   examples/estimation_examples/nzdir_as_pipeline.ipynb
   examples/estimation_examples/somocluSOM_demo.ipynb
   examples/estimation_examples/somocluSOMcluster_demo.ipynb
   examples/estimation_examples/test_sampled_summarizers.ipynb

.. toctree::
   :maxdepth: 1
   :caption: RAIL Evaluation (i.e.,Estimator Performance) Demos

   examples/evaluation_examples/demo.ipynb

.. toctree::
   :maxdepth: 1
   :caption: RAIL Analysis Pipeline Demos

   examples/goldenspike_examples/goldenspike.ipynb
